Keen | RowGroup Examples
Description: RowGroup examples

# Customer Relationship Management

New Order

### RowGroup Examples

Reports
RowGroup adds this ability to DataTables with the ability to customise the start and end grouping rows displayed in the DataTable, letting you integrate the summarised data to fit perfectly in with your site. See official documentation here.

### RowGroup DataTable

Record ID | Order ID | Country | Ship City | Ship Address | Company Agent | Company Name | Ship Date | Status | Type | Actions
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
33 | 68428-725 | China | Zhangcun | 3 Goodland Terrace | Pavel Kringe | Goldner-Lehner | 4/2/2017 | 4 | 1 |
22 | 49348-055 | China | Guxi | 45 Butterfield Street | Yardley Wetherell | Gerlach-Schultz | 4/3/2017 | 2 | 2 |
12 | 0185-0130 | China | Jiamachi | 23 Walton Pass | Norri Foldes | Strosin, Nitzsche and Wisozk | 4/2/2017 | 3 | 1 |
9 | 0404-0360 | Colombia | San Carlos | 38099 Ilene Hill | Freida Morby | Haley, Schamberger and Durgan | 3/31/2017 | 2 | 1 |
8 | 64980-196 | Croatia | Vinica | 0 Elka Street | Hazlett Kite | Streich LLC | 8/5/2016 | 6 | 1 |
29 | 58411-198 | Ethiopia | Kombolcha | 91066 Amoth Court | Tuck O'Dowgaine | Simonis, Rowe and Davis | 5/6/2017 | 1 | 1 |
27 | 51523-026 | Germany | Erfurt | 132 Chive Way | Lonnie Haycox | Feest Group | 4/24/2018 | 1 | 3 |
2 | 63629-4697 | Indonesia | Cihaur | 01652 Fulton Trail | Emelita Giraldez | Rosenbaum-Reichel | 8/6/2017 | 6 | 3 |
20 | 42291-712 | Indonesia | Kembang | 9029 Blackbird Point | Leonora Chevin | Mann LLC | 9/6/2017 | 2 | 3 |
4 | 67457-428 | Indonesia | Talok | 3050 Buell Terrace | Evangeline Cure | Pfannerstill-Treutel | 7/2/2016 | 1 | 3 |
25 | 0093-1016 | Indonesia | Merdeka | 3150 Cherokee Center | Gusti Clamp | Stokes Group | 4/12/2018 | 6 | 2 |
38 | 49349-123 | Indonesia | Pule | 77292 Bonner Plaza | Alfonse Lawrance | Schuppe-Harber | 4/14/2017 | 1 | 3 |
24 | 54569-0175 | Japan | Minato | 077 Hoffman Center | Chrissie Jeromson | Brakus-McCullough | 11/26/2017 | 2 | 1 |
32 | 62678-207 | Libya | Zuwārah | 82 Thackeray Pass | Freda Arnall | Dicki, Morar and Stiedemann | 7/22/2016 | 3 | 3 |
21 | 64679-154 | Mongolia | Sharga | 102 Holmberg Park | Tannie Seakes | Blanda Group | 7/31/2016 | 6 | 3 |
34 | 0363-0724 | Morocco | Temara | 9550 Weeping Birch Crossing | Felix Nazaret | Waters, Quigley and Keeling | 6/4/2016 | 5 | 3 |
39 | 17089-415 | Palestinian Territory | Za‘tarah | 42806 Ridgeview Terrace | Kessiah Chettoe | Mraz LLC | 3/4/2017 | 5 | 2 |
35 | 37000-102 | Paraguay | Los Cedrales | 1 Ridge Oak Way | Penrod Allanby | Rodriguez Group | 3/5/2018 | 2 | 3 |
40 | 51327-510 | Philippines | Esperanza | 4 Linden Court | Natka Fairbanks | Mueller-Greenholt | 6/21/2017 | 3 | 3 |
36 | 55289-002 | Philippines | Dologon | 9 Vidon Terrace | Hubey Passby | Lemke-Hermiston | 6/29/2017 | 2 | 3 |
31 | 55154-8284 | Philippines | Talisay | 09 Sachtjen Junction | Bryna MacCracken | Hyatt-Witting | 7/22/2017 | 2 | 1 |
14 | 40076-953 | Portugal | Burgau | 52550 Crownhardt Court | Sioux Kneath | Rice, Cole and Spinka | 10/11/2017 | 4 | 1 |
15 | 36987-3005 | Portugal | Bacelo | 548 Morrow Terrace | Christa Jacmar | Brakus-Hansen | 8/17/2017 | 1 | 2 |
30 | 27495-006 | Portugal | Arrifes | 3 Fairfield Junction | Vernon Cosham | Kreiger-Nicolas | 2/8/2017 | 4 | 2 |
23 | 47593-438 | Portugal | Viso | 97 Larry Center | Bryn Peascod | Larkin and Sons | 5/22/2016 | 6 | 1 |
17 | 36987-2542 | Russia | Novokizhinginsk | 19427 Sloan Road | Jerrome Colvie | Kreiger, Glover and Connelly | 3/4/2016 | 3 | 1 |
16 | 67510-0062 | South Africa | Pongola | 02534 Hauk Trail | Shandee Goracci | Bergnaum, Thiel and Schuppe | 7/24/2016 | 5 | 3 |
37 | 15127-874 | Tanzania | Nanganga | 33 Anniversary Parkway | Magdaia Rotlauf | Hettinger, Medhurst and Heaney | 2/18/2018 | 3 | 1 |
10 | 52125-267 | Thailand | Maha Sarakham | 8696 Barby Pass | Obed Helian | Labadie, Predovic and Hammes | 1/26/2017 | 1 | 3 |
19 | 47781-264 | Ukraine | Yasinya | 1481 Sauthoff Place | Lombard Luthwood | Haag LLC | 1/21/2016 | 1 | 2 |
Record ID | Order ID | Country | Ship City | Ship Address | Company Agent | Company Name | Ship Date | Status | Type | Actions

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!